package com.example.austime;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

import com.example.austime.model.Timer;

import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Calendar;

import static android.content.ContentValues.TAG;

public class DatabaseHandler extends SQLiteOpenHelper {
    //The Android's default system path of your application database.
    private static String DB_PATH = "/data/data/com.example.austime/databases/";
    public static String DB_NAME = "db_austime.db";
    private static  String table_Name ="timer";
    SQLiteDatabase db ;


    private SQLiteDatabase myDataBase;
    private final Context myContext;
    /**
     * Constructor
     * Takes and keeps a reference of the passed context in order to access to the application assets and resources.
     * @param context
     */
    public DatabaseHandler(Context context) {

        super(context, DB_NAME, null, 1);
        this.myContext = context;
    }

    /**
     * Creates a empty database on the system and rewrites it with your own database.
     * */
    public void createDataBase() throws IOException {
        boolean dbExist = checkDataBase();
        if(dbExist){
            Log.i(TAG, "createDataBase DB already exist **************: ");
        }else{
            //By calling this method and empty database will be created into the default system path
            //of your application so we are gonna be able to overwrite that database with our database.
            this.getReadableDatabase();
            try {
                copyDataBase();
            } catch (IOException e) {
                throw new Error("Error copying database");
            }
        }
    }

    /**
     * Check if the database already exist to avoid re-copying the file each time you open the application.
     * @return true if it exists, false if it doesn't
     */
    private boolean checkDataBase(){
        SQLiteDatabase checkDB = null;
        try{
            String myPath = DB_PATH + DB_NAME;
            checkDB = SQLiteDatabase.openDatabase(myPath, null, SQLiteDatabase.OPEN_READONLY);

        }catch(SQLiteException e){
            //database does't exist yet.
            Log.i(TAG, "createDataBase DB do not  exist **************: ");

        }
        if(checkDB != null){
            checkDB.close();
        }
        return checkDB != null ? true : false;
    }
    /**
     * Copies your database from your local assets-folder to the just created empty database in the
     * system folder, from where it can be accessed and handled.
     * This is done by transfering bytestream.
     * */
    private void copyDataBase() throws IOException{

        //Open your local db as the input stream
        InputStream myInput = myContext.getAssets().open(DB_NAME);

        // Path to the just created empty db
        String outFileName = DB_PATH + DB_NAME;

        //Open the empty db as the output stream
        OutputStream myOutput = new FileOutputStream(outFileName);

        //transfer bytes from the inputfile to the outputfile
        byte[] buffer = new byte[1024];
        int length;
        while ((length = myInput.read(buffer))>0){
            myOutput.write(buffer, 0, length);
        }

        Log.i(TAG, "createDataBase DB already exist **************:*********data copied succefully ");

        //Close the streams
        myOutput.flush();
        myOutput.close();
        myInput.close();
    }

    public void openDataBase() throws SQLException {
        //Open the database
        String myPath = DB_PATH + DB_NAME;
        myDataBase = SQLiteDatabase.openDatabase(myPath, null, SQLiteDatabase.OPEN_READONLY);
    }
    @Override
    public synchronized void close() {
        if(myDataBase != null)
            myDataBase.close();
        super.close();
    }

    @Override
    public void onCreate(SQLiteDatabase db) {
    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
    }

    public long insertData(String title, String date, String start_time, String end_time, String duree){

        ContentValues values = new ContentValues();
        myDataBase = this.getWritableDatabase();
        values.put("title", title);
        values.put("date", date);
        values.put("start_time", start_time);
        values.put("end_time", end_time);
        values.put("time",duree);
        return myDataBase.insert(table_Name, null, values);
    }

   public Cursor viewdata(){
        SQLiteDatabase myDataBase= this.getReadableDatabase();
        String query = "select * from "+table_Name;
       Cursor cursor = myDataBase.rawQuery(query, null);
       return cursor;
   }


    ArrayList<Timer> taskList;

    public ArrayList<Timer> getAll() {

        Calendar cal = Calendar.getInstance();
        //SQLiteDatabase db = this.getReadableDatabase();
        String sql = "SELECT DISTINCT  * FROM " + table_Name;
        Cursor cursor = db.rawQuery(sql, null);
        taskList = new ArrayList<>();

        if (cursor. moveToFirst() ) {
            do {
                //cursor.moveToNext();
                Timer timerInfo = new Timer();
                timerInfo.setId(cursor.getInt(0));
                timerInfo.setTitle(cursor.getString(1).trim());

                long l = cursor.getLong(cursor.getColumnIndexOrThrow(cursor.getColumnName(2)));
                cal.setTimeInMillis(l);
                timerInfo.setStartDate(cal);
                timerInfo.setTime(cursor.getInt(3));
                taskList.add(timerInfo);

            }while (cursor.moveToNext());
        }
        //getRowCount(cursor);

        cursor.close();
        db.close();
        return taskList;

    }


}











